import { getParsedType, hasKeys, INVALID, isOneOf, OK, ParsedType } from "@postgresql-typed/util";
import { PgTPBase } from "../../util/PgTPBase.js";
import { PgTPConstructorBase } from "../../util/PgTPConstructorBase.js";
import { UUID } from "../UUID/UUID.js";
import { Character } from "./Character.js";
import { CharacterVarying } from "./CharacterVarying.js";
import { Name } from "./Name.js";
class TextConstructorClass extends PgTPConstructorBase {
    constructor() {
        super();
    }
    _parse(context) {
        if (context.data.length !== 1) {
            this.setIssueForContext(context, context.data.length > 1
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 1,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 1,
                    exact: true,
                });
            return INVALID;
        }
        const [argument] = context.data, allowedTypes = [ParsedType.string, ParsedType.object], parsedType = getParsedType(argument);
        if (!isOneOf(allowedTypes, parsedType)) {
            this.setIssueForContext(context, {
                code: "invalid_type",
                expected: allowedTypes,
                received: parsedType,
            });
            return INVALID;
        }
        switch (parsedType) {
            case ParsedType.string:
                return OK(new TextClass(argument));
            default:
                return this._parseObject(context, argument);
        }
    }
    _parseObject(context, argument) {
        if (this.isText(argument))
            return OK(new TextClass(argument.value));
        if (Character.isAnyCharacter(argument))
            return OK(new TextClass(argument.value));
        if (CharacterVarying.isAnyCharacterVarying(argument))
            return OK(new TextClass(argument.value));
        if (Name.isName(argument))
            return OK(new TextClass(argument.value));
        if (UUID.isUUID(argument))
            return OK(new TextClass(argument.value));
        const parsedObject = hasKeys(argument, [["value", "string"]]);
        if (parsedObject.success)
            return OK(new TextClass(parsedObject.obj.value));
        switch (true) {
            case parsedObject.otherKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "unrecognized_keys",
                    keys: parsedObject.otherKeys,
                });
                break;
            case parsedObject.missingKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "missing_keys",
                    keys: parsedObject.missingKeys,
                });
                break;
            case parsedObject.invalidKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "invalid_key_type",
                    ...parsedObject.invalidKeys[0],
                });
                break;
        }
        return INVALID;
    }
    isText(object) {
        return object instanceof TextClass;
    }
}
const Text = new TextConstructorClass();
class TextClass extends PgTPBase {
    constructor(_text) {
        super();
        this._text = _text;
    }
    _equals(context) {
        //@ts-expect-error - _equals receives the same context as _parse
        const parsed = Text.safeFrom(...context.data);
        if (parsed.success) {
            return OK({
                equals: parsed.data.toString() === this.toString(),
                data: parsed.data,
            });
        }
        this.setIssueForContext(context, parsed.error.issue);
        return INVALID;
    }
    toString() {
        return this._text;
    }
    toJSON() {
        return {
            value: this._text,
        };
    }
    get text() {
        return this._text;
    }
    set text(text) {
        const parsed = Text.safeFrom(text);
        if (parsed.success)
            this._text = parsed.data.toString();
        else
            throw parsed.error;
    }
    get value() {
        return this._text;
    }
    set value(text) {
        const parsed = Text.safeFrom(text);
        if (parsed.success)
            this._text = parsed.data.toString();
        else
            throw parsed.error;
    }
    get postgres() {
        return this._text;
    }
    set postgres(text) {
        const parsed = Text.safeFrom(text);
        if (parsed.success)
            this._text = parsed.data.toString();
        else
            throw parsed.error;
    }
}
export { Text };
//# sourceMappingURL=Text.js.map