import { DateTime, Zone } from "luxon";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Date } from "./Date.js";
import { Time } from "./Time.js";
import { TimestampStyle, TimestampStyleType } from "./TimestampTZ.js";
interface TimestampObject {
    year: number;
    month: number;
    day: number;
    hour: number;
    minute: number;
    second: number;
}
interface Timestamp {
    year: number;
    month: number;
    day: number;
    hour: number;
    minute: number;
    second: number;
    value: number;
    postgres: string;
    /**
     * @param style The style to use when converting the timestamp to a string. Defaults to `ISO`.
     * @returns The timestamp as a string.
     * @example
     * const timestamp = Timestamp.from("01-01-2023 20:00:23.123456");
     *
     * timestamp.toString(); // "2023-01-01T20:00:23.123456Z"
     * timestamp.toString("ISO"); // "2023-01-01T20:00:23.123456Z"
     * timestamp.toString("ISO-Date"); // "2023-01-01"
     * timestamp.toString("ISO-Time"); // "20:00:23.123456"
     * timestamp.toString("ISO-Duration"); // "P2023Y1M1DT20H0M23.123456S"
     * timestamp.toString("ISO-Duration-Short"); // "P2023Y1M1DT20H23.123456S"
     * timestamp.toString("ISO-Duration-Basic"); // "P20230101T200023.123456S"
     * timestamp.toString("ISO-Duration-Extended"); // "P2023-01-01T20:00:23.123456S"
     * timestamp.toString("POSIX"); // "2023-01-01 20:00:23.123456"
     * timestamp.toString("PostgreSQL"); // "Sunday January 01 2023 20:00:23.123456"
     * timestamp.toString("PostgreSQL-Short"); // "Sun Jan 01 2023 20:00:23.123456"
     * timestamp.toString("SQL"); // "2023-01 01 20:00:23.123456"
     */
    toString(style?: TimestampStyle | TimestampStyleType): string;
    /**
     * @returns The timestamp as a unix timestamp.
     */
    toNumber(): number;
    toJSON(): TimestampObject;
    toDate(): Date;
    toTime(): Time;
    /**
     * @param zone The zone to convert the timestamp to. Defaults to 'local'.
     */
    toDateTime(zone?: string | Zone | undefined): DateTime;
    /**
     * @param zone The zone to convert the timestamp to. Defaults to 'local'.
     */
    toJSDate(zone?: string | Zone | undefined): globalThis.Date;
    equals(string: string): boolean;
    equals(unixTimestamp: number): boolean;
    equals(year: number, month: number, day: number, hour: number, minute: number, second: number): boolean;
    equals(timestamp: Timestamp | globalThis.Date | DateTime): boolean;
    equals(object: TimestampObject): boolean;
    safeEquals(string: string): SafeEquals<Timestamp>;
    safeEquals(unixTimestamp: number): SafeEquals<Timestamp>;
    safeEquals(year: number, month: number, day: number, hour: number, minute: number, second: number): SafeEquals<Timestamp>;
    safeEquals(timestamp: Timestamp | globalThis.Date | DateTime): SafeEquals<Timestamp>;
    safeEquals(object: TimestampObject): SafeEquals<Timestamp>;
}
interface TimestampConstructor {
    from(string: string): Timestamp;
    from(unixTimestamp: number): Timestamp;
    from(year: number, month: number, day: number, hour: number, minute: number, second: number): Timestamp;
    from(timestamp: Timestamp | globalThis.Date | DateTime): Timestamp;
    from(object: TimestampObject): Timestamp;
    safeFrom(string: string): SafeFrom<Timestamp>;
    safeFrom(unixTimestamp: number): SafeFrom<Timestamp>;
    safeFrom(year: number, month: number, day: number, hour: number, minute: number, second: number): SafeFrom<Timestamp>;
    safeFrom(timestamp: Timestamp | globalThis.Date | DateTime): SafeFrom<Timestamp>;
    safeFrom(object: TimestampObject): SafeFrom<Timestamp>;
    /**
     * Returns `true` if `object` is a `Timestamp`, `false` otherwise.
     */
    isTimestamp(object: any): object is Timestamp;
}
declare const Timestamp: TimestampConstructor;
export { Timestamp, TimestampConstructor, TimestampObject };
