import { getParsedType, hasKeys, INVALID, isOneOf, OK, ParsedType } from "@postgresql-typed/util";
import { PgTPBase } from "../../util/PgTPBase.js";
import { PgTPConstructorBase } from "../../util/PgTPConstructorBase.js";
import { throwPgTPError } from "../../util/throwPgTPError.js";
class BoxConstructorClass extends PgTPConstructorBase {
    constructor() {
        super();
    }
    _parse(context) {
        const [argument, ...otherArguments] = context.data, allowedTypes = [ParsedType.number, ParsedType.string, ParsedType.object], parsedType = getParsedType(argument);
        if (parsedType !== ParsedType.number && context.data.length !== 1) {
            this.setIssueForContext(context, context.data.length > 1
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 1,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 1,
                    exact: true,
                });
            return INVALID;
        }
        if (!isOneOf(allowedTypes, parsedType)) {
            this.setIssueForContext(context, {
                code: "invalid_type",
                expected: allowedTypes,
                received: parsedType,
            });
            return INVALID;
        }
        switch (parsedType) {
            case "string":
                return this._parseString(context, argument);
            case "number":
                return this._parseNumber(context, argument, otherArguments);
            default:
                return this._parseObject(context, argument);
        }
    }
    _parseString(context, argument) {
        // Remove all whitespace
        argument = argument.replaceAll(/\s/g, "");
        if (argument.startsWith("((") && argument.endsWith("))"))
            argument = argument.slice(1, -1);
        if (/^\((?:-?\d+(\.\d+)?|NaN),(?:-?\d+(\.\d+)?|NaN)\),\((?:-?\d+(\.\d+)?|NaN),(?:-?\d+(\.\d+)?|NaN)\)$/.test(argument)) {
            const [x1, y1, x2, y2] = argument.split(",").map(c => Number.parseFloat(c.replace("(", "")));
            return OK(new BoxClass(x1, y1, x2, y2));
        }
        this.setIssueForContext(context, {
            code: "invalid_string",
            received: argument,
            expected: "LIKE (x1,y1),(x2,y2)",
        });
        return INVALID;
    }
    _parseNumber(context, argument, otherArguments) {
        const totalLength = otherArguments.length + 1;
        if (totalLength !== 4) {
            this.setIssueForContext(context, totalLength > 4
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 4,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 4,
                    exact: true,
                });
            return INVALID;
        }
        for (const otherArgument of otherArguments) {
            const allowedTypes = [ParsedType.number], parsedType = getParsedType(otherArgument);
            if (!isOneOf(allowedTypes, parsedType)) {
                this.setIssueForContext(context, {
                    code: "invalid_type",
                    expected: allowedTypes,
                    received: parsedType,
                });
                return INVALID;
            }
        }
        const [x1, y1, x2, y2] = [argument, ...otherArguments];
        return OK(new BoxClass(x1, y1, x2, y2));
    }
    _parseObject(context, argument) {
        if (this.isBox(argument))
            return OK(new BoxClass(argument.x1, argument.y1, argument.x2, argument.y2));
        const parsedObject = hasKeys(argument, [
            ["x1", "number"],
            ["y1", "number"],
            ["x2", "number"],
            ["y2", "number"],
        ]);
        if (parsedObject.success)
            return OK(new BoxClass(parsedObject.obj.x1, parsedObject.obj.y1, parsedObject.obj.x2, parsedObject.obj.y2));
        switch (true) {
            case parsedObject.otherKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "unrecognized_keys",
                    keys: parsedObject.otherKeys,
                });
                break;
            case parsedObject.missingKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "missing_keys",
                    keys: parsedObject.missingKeys,
                });
                break;
            case parsedObject.invalidKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "invalid_key_type",
                    ...parsedObject.invalidKeys[0],
                });
                break;
        }
        return INVALID;
    }
    isBox(object) {
        return object instanceof BoxClass;
    }
}
const Box = new BoxConstructorClass();
class BoxClass extends PgTPBase {
    constructor(_x1, _y1, _x2, _y2) {
        super();
        this._x1 = _x1;
        this._y1 = _y1;
        this._x2 = _x2;
        this._y2 = _y2;
    }
    _equals(context) {
        //@ts-expect-error - _equals receives the same context as _parse
        const parsed = Box.safeFrom(...context.data);
        if (parsed.success) {
            return OK({
                equals: parsed.data.toString() === this.toString(),
                data: parsed.data,
            });
        }
        this.setIssueForContext(context, parsed.error.issue);
        return INVALID;
    }
    toString() {
        return `(${this._x1},${this._y1}),(${this._x2},${this._y2})`;
    }
    toJSON() {
        return {
            x1: this._x1,
            y1: this._y1,
            x2: this._x2,
            y2: this._y2,
        };
    }
    get x1() {
        return this._x1;
    }
    set x1(x1) {
        const parsedType = getParsedType(x1);
        if (parsedType !== ParsedType.number) {
            throwPgTPError({
                code: "invalid_type",
                expected: [ParsedType.number],
                received: parsedType,
            });
        }
        this._x1 = x1;
    }
    get y1() {
        return this._y1;
    }
    set y1(y1) {
        const parsedType = getParsedType(y1);
        if (parsedType !== ParsedType.number) {
            throwPgTPError({
                code: "invalid_type",
                expected: [ParsedType.number],
                received: parsedType,
            });
        }
        this._y1 = y1;
    }
    get x2() {
        return this._x2;
    }
    set x2(x2) {
        const parsedType = getParsedType(x2);
        if (parsedType !== ParsedType.number) {
            throwPgTPError({
                code: "invalid_type",
                expected: [ParsedType.number],
                received: parsedType,
            });
        }
        this._x2 = x2;
    }
    get y2() {
        return this._y2;
    }
    set y2(y2) {
        const parsedType = getParsedType(y2);
        if (parsedType !== ParsedType.number) {
            throwPgTPError({
                code: "invalid_type",
                expected: [ParsedType.number],
                received: parsedType,
            });
        }
        this._y2 = y2;
    }
    get value() {
        return this.toString();
    }
    set value(box) {
        const parsed = Box.safeFrom(box);
        if (parsed.success) {
            this._x1 = parsed.data.x1;
            this._y1 = parsed.data.y1;
            this._x2 = parsed.data.x2;
            this._y2 = parsed.data.y2;
        }
        else
            throw parsed.error;
    }
    get postgres() {
        return this.toString();
    }
    set postgres(box) {
        const parsed = Box.safeFrom(box);
        if (parsed.success) {
            this._x1 = parsed.data.x1;
            this._y1 = parsed.data.y1;
            this._x2 = parsed.data.x2;
            this._y2 = parsed.data.y2;
        }
        else
            throw parsed.error;
    }
}
function isBox(object) {
    return object instanceof BoxClass || object instanceof BoxConstructorClass;
}
export { Box, isBox };
//# sourceMappingURL=Box.js.map