import { getParsedType, hasKeys, INVALID, isOneOf, OK, ParsedType } from "@postgresql-typed/util";
import { PgTPBase } from "../../util/PgTPBase.js";
import { PgTPConstructorBase } from "../../util/PgTPConstructorBase.js";
import { throwPgTPError } from "../../util/throwPgTPError.js";
import { Point } from "./Point.js";
class LineSegmentConstructorClass extends PgTPConstructorBase {
    constructor() {
        super();
    }
    _parse(context) {
        const [argument, ...otherArguments] = context.data, allowedTypes = [ParsedType.string, ParsedType.object, ParsedType.array], parsedType = getParsedType(argument);
        if (parsedType !== ParsedType.object && context.data.length !== 1) {
            this.setIssueForContext(context, context.data.length > 1
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 1,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 1,
                    exact: true,
                });
            return INVALID;
        }
        if (!isOneOf(allowedTypes, parsedType)) {
            this.setIssueForContext(context, {
                code: "invalid_type",
                expected: allowedTypes,
                received: parsedType,
            });
            return INVALID;
        }
        switch (parsedType) {
            case "string":
                return this._parseString(context, argument);
            case "array":
                return this._parseObject(context, argument[0], argument);
            default:
                return this._parseObject(context, argument, otherArguments);
        }
    }
    _parseString(context, argument) {
        // Remove all whitespace
        argument = argument.replaceAll(/\s/g, "");
        if (/^\[?\((?:-?\d+(\.\d+)?|NaN),(?:-?\d+(\.\d+)?|NaN)\),\((?:-?\d+(\.\d+)?|NaN),(?:-?\d+(\.\d+)?|NaN)\)]?$/.test(argument)) {
            if (argument.startsWith("[(") && argument.endsWith(")]"))
                argument = argument.slice(1, -1);
            const [a, b] = argument
                .split("),(")
                .join("), (")
                .split(", ")
                .map(p => Point.safeFrom(p));
            /* c8 ignore start */
            if (!a.success) {
                this.setIssueForContext(context, a.error.issue);
                return INVALID;
            }
            if (!b.success) {
                this.setIssueForContext(context, b.error.issue);
                return INVALID;
            }
            /* c8 ignore stop */
            return OK(new LineSegmentClass(a.data, b.data));
        }
        this.setIssueForContext(context, {
            code: "invalid_string",
            received: argument,
            expected: "LIKE [(x1,y1),(x2,y2)]",
        });
        return INVALID;
    }
    _parseObject(context, argument, otherArguments) {
        if (context.data.length > 2) {
            this.setIssueForContext(context, {
                code: "too_big",
                type: "arguments",
                maximum: 2,
                inclusive: true,
            });
            return INVALID;
        }
        const secondArgument = otherArguments[0], parsedType = getParsedType(secondArgument);
        //Input should be [LineSegment]
        if (LineSegment.isLineSegment(argument)) {
            if (parsedType !== "undefined") {
                this.setIssueForContext(context, {
                    code: "too_big",
                    type: "arguments",
                    maximum: 1,
                    exact: true,
                });
                return INVALID;
            }
            return OK(new LineSegmentClass(argument.a, argument.b));
        }
        //Input should be [Point, Point]
        if (Point.isPoint(argument)) {
            if (parsedType === "undefined") {
                this.setIssueForContext(context, {
                    code: "too_small",
                    type: "arguments",
                    minimum: 2,
                    exact: true,
                });
                return INVALID;
            }
            const parsedObject = Point.safeFrom(secondArgument);
            if (!parsedObject.success) {
                this.setIssueForContext(context, parsedObject.error.issue);
                return INVALID;
            }
            return OK(new LineSegmentClass(argument, parsedObject.data));
        }
        //Input should be [LineSegmentObject | RawLineSegmentObject]
        if (parsedType !== "undefined") {
            this.setIssueForContext(context, {
                code: "too_big",
                type: "arguments",
                maximum: 1,
                exact: true,
            });
            return INVALID;
        }
        const parsedObject = hasKeys(argument, [
            ["a", "object"],
            ["b", "object"],
        ]);
        if (!parsedObject.success) {
            switch (true) {
                case parsedObject.otherKeys.length > 0:
                    this.setIssueForContext(context, {
                        code: "unrecognized_keys",
                        keys: parsedObject.otherKeys,
                    });
                    break;
                case parsedObject.missingKeys.length > 0:
                    this.setIssueForContext(context, {
                        code: "missing_keys",
                        keys: parsedObject.missingKeys,
                    });
                    break;
                case parsedObject.invalidKeys.length > 0:
                    this.setIssueForContext(context, {
                        code: "invalid_key_type",
                        ...parsedObject.invalidKeys[0],
                    });
                    break;
            }
            return INVALID;
        }
        const { a, b } = parsedObject.obj, parsedA = Point.safeFrom(a), parsedB = Point.safeFrom(b);
        if (!parsedA.success) {
            this.setIssueForContext(context, parsedA.error.issue);
            return INVALID;
        }
        if (!parsedB.success) {
            this.setIssueForContext(context, parsedB.error.issue);
            return INVALID;
        }
        return OK(new LineSegmentClass(parsedA.data, parsedB.data));
    }
    isLineSegment(object) {
        return object instanceof LineSegmentClass;
    }
}
const LineSegment = new LineSegmentConstructorClass();
class LineSegmentClass extends PgTPBase {
    constructor(_a, _b) {
        super();
        this._a = _a;
        this._b = _b;
    }
    _equals(context) {
        //@ts-expect-error - _equals receives the same context as _parse
        const parsed = LineSegment.safeFrom(...context.data);
        if (parsed.success) {
            return OK({
                equals: parsed.data.toString() === this.toString(),
                data: parsed.data,
            });
        }
        this.setIssueForContext(context, parsed.error.issue);
        return INVALID;
    }
    toString() {
        return `[${this._a.toString()},${this._b.toString()}]`;
    }
    toJSON() {
        return {
            a: this._a.toJSON(),
            b: this._b.toJSON(),
        };
    }
    get a() {
        return this._a;
    }
    set a(a) {
        const parsed = Point.safeFrom(a);
        if (!parsed.success)
            throwPgTPError(parsed.error.issue);
        this._a = parsed.data;
    }
    get b() {
        return this._b;
    }
    set b(b) {
        const parsed = Point.safeFrom(b);
        if (!parsed.success)
            throwPgTPError(parsed.error.issue);
        this._b = parsed.data;
    }
    get value() {
        return this.toString();
    }
    set value(lineSegment) {
        const parsed = LineSegment.safeFrom(lineSegment);
        if (parsed.success) {
            this._a = parsed.data.a;
            this._b = parsed.data.b;
        }
        else
            throw parsed.error;
    }
    get postgres() {
        return this.toString();
    }
    set postgres(lineSegment) {
        const parsed = LineSegment.safeFrom(lineSegment);
        if (parsed.success) {
            this._a = parsed.data.a;
            this._b = parsed.data.b;
        }
        else
            throw parsed.error;
    }
}
export { LineSegment };
//# sourceMappingURL=LineSegment.js.map